TPResult class
Constructors
- TPResult()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
handleAdUnitId(
List< String> adUnitIds) → Future<List< String> > - 多条 TradPlus 广告位 ID 按缓存 eCPM 从高到低排序
-
handleMix(
List< Map< mixAdInfoList) → Future<String, dynamic> >List< Map< >String, dynamic> > - TradPlus 广告位与第三方自定义价格混合比价,结果从高到低排序 mixAdInfoList 每项传入 adUnitId 或 ecpm 其一即可
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited